==> haskell-js-chart-2.9.4.1-8-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-js-chart.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 js-chart
version:              2.9.4.1
visibility:           public
id:                   js-chart-2.9.4.1-IBsFHDloWlsCcv9nYHmzO5
key:                  js-chart-2.9.4.1-IBsFHDloWlsCcv9nYHmzO5
license:              MIT
copyright:
    Jonas Carpay 2020, Neil Mitchell 2014-2020, Chart.js contributors 2020

maintainer:           Jonas Carpay <jonascarpay@gmail.com>
author:               Jonas Carpay <jonascarpay@gmail.com>
homepage:             https://github.com/jonascarpay/js-chart#readme
synopsis:             Obtain minified chart.js code
description:
    This package bundles the minified <http://www.chartjs.org/ chart.js> code into a Haskell package, so it can be depended upon by Cabal packages.
    The first three components of the version number match the upstream chart.js version.
    The package is designed to meet the redistribution requirements of downstream users (e.g. Debian).
    This package is a fork of <https://hackage.haskell.org/package/js-flot js-flot> using chart.js instead of flot.

category:             Javascript
abi:                  5893b5e65d5b5b079f89bd8d8416554c
exposed:              True
exposed-modules:      Language.Javascript.Chart
hidden-modules:       Paths_js_chart
import-dirs:          /usr/lib/ghc-9.4.8/site-local/js-chart-2.9.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/js-chart-2.9.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/js-chart-2.9.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-js-chart
hs-libraries:         HSjs-chart-2.9.4.1-IBsFHDloWlsCcv9nYHmzO5
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-js-chart/html/js-chart.haddock
haddock-html:         /usr/share/doc/haskell-js-chart/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-js-chart-2.9.4.1-9-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-js-chart.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 js-chart
version:              2.9.4.1
visibility:           public
id:                   js-chart-2.9.4.1-ApLUoR9Z74r1yyHu8DdEAV
key:                  js-chart-2.9.4.1-ApLUoR9Z74r1yyHu8DdEAV
license:              MIT
copyright:
    Jonas Carpay 2020, Neil Mitchell 2014-2020, Chart.js contributors 2020

maintainer:           Jonas Carpay <jonascarpay@gmail.com>
author:               Jonas Carpay <jonascarpay@gmail.com>
homepage:             https://github.com/jonascarpay/js-chart#readme
synopsis:             Obtain minified chart.js code
description:
    This package bundles the minified <http://www.chartjs.org/ chart.js> code into a Haskell package, so it can be depended upon by Cabal packages.
    The first three components of the version number match the upstream chart.js version.
    The package is designed to meet the redistribution requirements of downstream users (e.g. Debian).
    This package is a fork of <https://hackage.haskell.org/package/js-flot js-flot> using chart.js instead of flot.

category:             Javascript
abi:                  7d480b4e6ce8f931afc0a5d25da0e1df
exposed:              True
exposed-modules:      Language.Javascript.Chart
hidden-modules:       Paths_js_chart
import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/js-chart-2.9.4.1
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/js-chart-2.9.4.1
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/js-chart-2.9.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-js-chart
hs-libraries:         HSjs-chart-2.9.4.1-ApLUoR9Z74r1yyHu8DdEAV
depends:              base-4.18.3.0
haddock-interfaces:   /usr/share/doc/haskell-js-chart/html/js-chart.haddock
haddock-html:         /usr/share/doc/haskell-js-chart/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
